@@ -73,16 +73,12 @@ qi_data_controller = QiDataController(qi_data_directory)
 #     index += 1
 #
 
-begin_trading_date = datetime.datetime(2016, 7, 11)
-end_trading_date = datetime.datetime(2016, 7, 11)
-instrument_id = "IC9999"
-interval = 5
-bar_type = EnumBarType.minute
-bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
-index = 1
+begin_date = datetime.datetime(2020, 1, 1)
+end_date = datetime.datetime(2020,1, 31)
+instrument_id = 'sc9999'
+bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, 1,EnumBarType.minute, begin_date, end_date)
 for bar in bar_series:
-    print("["+instrument_id+"]"+str(index)+":"+bar.to_string()+','+str(bar.pre_close)+bar.end_time.strftime('%Y%m%d %H%M%S%f'))
-    index += 1
+    print(bar)
 
 #
 # begin_trading_date = datetime.datetime(2017, 1, 1)
